@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2023
-;; Version: 1.7
+;; Version: 1.8
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/jinx
 ;; Keywords: convenience, text
@@ -738,7 +738,8 @@ The word will be associated with GROUP and get a prefix key."
       (setq list (jinx--add-suggestion list ht w "Suggestions from session")))
     (cl-loop for (key . fun) in jinx--save-keys
              for actions = (funcall fun nil key word) do
-             (unless (consp (car actions)) (setq actions (list actions)))
+             (when (and actions (not (consp (car actions))))
+               (setq actions (list actions)))
              (cl-loop for (k w a) in actions do
                       (push (propertize
                              (concat (propertize (if (stringp k) k (char-to-string k))
